@@ -40,16 +40,16 @@ $lang = array_merge($lang, array(
 	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'Здесь вы можете установить общие параметры конференции, дать ей имя и описание, а также указать часовой пояс и язык, которые будут использоваться по умолчанию.',
 	'CUSTOM_DATEFORMAT'				=> 'Другой…',
 	'DEFAULT_DATE_FORMAT'			=> 'Формат даты',
-	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Синтаксис идентичен функции <code><a href="http://www.php.net/date">date</a></code> языка PHP.',
+	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Синтаксис идентичен функции <code>date</code> языка PHP.',
 	'DEFAULT_LANGUAGE'				=> 'Язык конференции по умолчанию',
 	'DEFAULT_STYLE'					=> 'Стиль конференции по умолчанию',
 	'DISABLE_BOARD'					=> 'Отключить конференцию',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Конференция станет недоступной для посетителей. Также вы можете ввести короткое сообщение (до 255 символов), которое будут видеть посетители.',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Конференция станет недоступной для посетителей, за исключением администраторов и модераторов. Также вы можете ввести короткое сообщение (до 255 символов), которое будут видеть посетители.',
 	'OVERRIDE_STYLE'				=> 'Заменять стиль пользователя',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Стиль, выбранный пользователем, будет заменён стилем по умолчанию.',
 	'SITE_DESC'						=> 'Описание конференции',
 	'SITE_NAME'						=> 'Название конференции',
-	'SYSTEM_DST'					=> 'Сейчас действует летнее время (<abbr title="Летнее время">DST</abbr>)',
+	'SYSTEM_DST'					=> 'Сейчас действует летнее время',
 	'SYSTEM_TIMEZONE'				=> 'Часовой пояс для гостей',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Часовой пояс, используемый для отображения времени у незарегистрированных пользователей (гости, боты). Зарегистрированные пользователи настраивают свой часовой пояс при регистрации и могут изменить его в Личном разделе.',
 	'WARNINGS_EXPIRE'				=> 'Длительность предупреждений',
@@ -104,7 +104,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Путь к галерее аватар',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Путь к папке с загруженными в неё рисунками относительно корневой папки phpBB. Например, <samp>images/avatars/gallery</samp>.',
 	'AVATAR_STORAGE_PATH'			=> 'Папка для загрузки аватар',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Путь к папке относительно корневой папки phpBB. Например, <samp>images/avatars/upload</samp>.',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Путь к папке относительно корневой папки phpBB. Например, <samp>images/avatars/upload</samp>.<br />Загрузка аватар <strong>будет недоступна</strong>, если не разрещена запись в указанную папку.',
 	'MAX_AVATAR_SIZE'				=> 'Максимальные размеры аватар',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Ширина × высота (в пикселах).',
 	'MAX_FILESIZE'					=> 'Максимальный размер файла аватары',
@@ -298,7 +298,7 @@ $lang = array_merge($lang, array(
 	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'Использовать шум на переднем плане, чтобы усложнить распознавание картинки.',
 	'CAPTCHA_GD_X_GRID'						=> 'Фоновый шум по горизонтали',
 	'CAPTCHA_GD_X_GRID_EXPLAIN'				=> 'Используйте меньшее значение для усложнения распознавания картинки. Введите 0 для отключения шума по горизонтали.',
-	'CAPTCHA_GD_Y_GRID'						=> 'Фоновой шум по вертикали',
+	'CAPTCHA_GD_Y_GRID'						=> 'Фоновый шум по вертикали',
 	'CAPTCHA_GD_Y_GRID_EXPLAIN'				=> 'Используйте меньшее значение для усложнения распознавания картинки. Введите 0 для отключения шума по вертикали.',
 	'CAPTCHA_GD_WAVE'						=> 'Волновое искажение',
 	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'Использовать волновое искажение картинки.',
@@ -547,4 +547,4 @@ $lang = array_merge($lang, array(
 	'JAB_USERNAME_EXPLAIN'		=> 'Введите имя или существующий JID (идентификатор) зарегистрированного пользователя. Проверка имени производиться не будет. Если указано только имя, то ваш JID (идентификатор) будет составлен из этого имени и указанного выше имени сервера. В противном случае укажите существующий JID (идентификатор), например user@jabber.org.',
 ));
 
-?>
\ No newline at end of file
+?>
