@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Указанный файл загружен только частично',
 	'AVATAR_PHP_SIZE_NA'			=> 'Слишком большой размер файла аватары.<br />Не удалось определить максимальный размер, установленный в php.ini.',
 	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Слишком большой размер файла аватары. Максимально допустимый размер — %1$d %2$s.<br />Примечание: это ограничение установлено в файле php.ini и не может быть превышено.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'	=> 'Аватара не может быть загружена из-за превышения времени ожидания ответа сервера на запрос.',
 	'AVATAR_URL_INVALID'			=> 'Указанный адрес аватары недопустим.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Указанный файл аватары не найден.',
-	'AVATAR_WRONG_FILESIZE'			=> 'Размер файла аватары должен находиться в диапазоне от 0 до %1d %2s.',
+	'AVATAR_WRONG_FILESIZE'			=> 'Размер файла аватары должен находиться в диапазоне от 0 до %1$d %2$s.',
 	'AVATAR_WRONG_SIZE'				=> 'Размеры отправленной аватары — %5$d×%6$d. Размеры аватары должны быть не менее %1$d×%2$d, но не более %3$d×%4$d. Все размеры указаны в пикселах.',
 
 	'BACK_TO_TOP'			=> 'Вернуться к началу',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'				=> 'Модерировать',
 	'MODERATOR'				=> 'Модератор',
 	'MODERATORS'			=> 'Модераторы',
+	'MODULE_NOT_ACCESS'		=> 'Модуль недоступен',
+	'MODULE_NOT_FIND'		=> 'Не удалось найти модуль %s',
+	'MODULE_FILE_INCORRECT_CLASS'	=> 'Файл модуля %s не содержит необходимого класса [%s]',
 	'MONTH'					=> 'Месяц',
 	'MOVE'					=> 'Переместить',
 	'MSNM'					=> 'MSNM/WLM',
@@ -409,7 +413,8 @@ $lang = array_merge($lang, array(
 	// Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
 	'NUM_POSTS_IN_QUEUE'	=> array(
 		0		=> 'Нет сообщений в очереди',	// 0
-		1		=> 'Сообщений в очереди: %d',	// 1+
+		1		=> 'Сообщений в очереди: 1',	// 1
+		2		=> 'Сообщений в очереди: %d',	// 2+
 	),
 
 	'OCCUPATION'				=> 'Род занятий',
@@ -650,7 +655,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'Пользователей: <strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> 'Отслеженные ошибки PHP: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> 'Не удалось определить размеры изображения.',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'Не удалось определить размеры изображения. Проверьте правильность введённого адреса URL.',
 	'UNABLE_TO_DELIVER_FILE'=> 'Не удалось доставить файл.',
 	'UNKNOWN_BROWSER'		=> 'Неизвестный браузер',
 	'UNMARK_ALL'			=> 'Снять выделение',
@@ -721,9 +726,9 @@ $lang = array_merge($lang, array(
 	'WHO_IS_ONLINE'		=> 'Кто сейчас на конференции',
 	'WRONG_PASSWORD'	=> 'Вы ввели неверный пароль.',
 
-	'WRONG_DATA_COLOUR'			=> 'Введённо неправильное значение цвета.',
-	'WRONG_DATA_ICQ'			=> 'Введённый номер не являются правильным номером ICQ.',
-	'WRONG_DATA_JABBER'			=> 'Введённое имя не является правильным именем Jabber.',
+	'WRONG_DATA_COLOUR'			=> 'Введено неправильное значение цвета.',
+	'WRONG_DATA_ICQ'			=> 'Введён неправильный номер ICQ.',
+	'WRONG_DATA_JABBER'			=> 'Введено неправильное имя Jabber.',
 	'WRONG_DATA_LANG'			=> 'Указан неправильный язык.',
 	'WRONG_DATA_WEBSITE'		=> 'Адрес сайта должен быть правильной ссылкой, включающей наименование протокола. Например, http://www.example.com/.',
 	'WROTE'						=> 'писал(а)',
@@ -867,26 +872,26 @@ $lang = array_merge($lang, array(
 		'-1'	=> '[UTC − 1] Азорские острова, острова Зелёного мыса',
 		'0'		=> '[UTC] Время по Гринвичу: Дублин, Лондон, Лиссабон, Эдинбург',
 		'1'		=> '[UTC + 1] Берлин, Мадрид, Париж, Рим, Западная Центральная Африка',
-		'2'		=> '[UTC + 2] Афины, Вильнюс, Киев, Рига, Таллин, Центральная Африка',
-		'3'		=> '[UTC + 3] Багдад, Калининград, Минск, Кувейт, Эр-рияд, Найроби',
+		'2'		=> '[UTC + 2] Афины, Вильнюс, Калининград, Киев, Рига, Таллин, Центральная Африка',
+		'3'		=> '[UTC + 3] Багдад, Волгоград, Минск, Москва, Кувейт, Санкт-Петербург, Эр-рияд, Найроби',
 		'3.5'	=> '[UTC + 3:30] Тегеран',
-		'4'		=> '[UTC + 4] Волгоград, Москва, Самара, Санкт-Петербург, Баку, Ереван, Тбилиси',
+		'4'		=> '[UTC + 4] Ижевск, Самара, Баку, Ереван, Тбилиси',
 		'4.5'	=> '[UTC + 4:30] Кабул',
-		'5'		=> '[UTC + 5] Исламабад, Карачи,  Ташкент',
+		'5'		=> '[UTC + 5] Екатеринбург, Исламабад, Карачи, Оренбург, Ташкент',
 		'5.5'	=> '[UTC + 5:30] Бомбей, Калькутта, Мадрас, Нью-Дели',
 		'5.75'	=> '[UTC + 5:45] Катманду',
-		'6'		=> '[UTC + 6] Алматы, Астана, Екатеринбург, Оренбург',
+		'6'		=> '[UTC + 6] Алматы, Астана, Новосибирск, Омск',
 		'6.5'	=> '[UTC + 6:30] Янгон',
-		'7'		=> '[UTC + 7] Бангкок, Джакарта, Новосибирск, Омск, Ханой',
-		'8'		=> '[UTC + 8] Гонконг, Красноярск, Пекин, Сингапур',
+		'7'		=> '[UTC + 7] Бангкок, Джакарта, Красноярск, Ханой',
+		'8'		=> '[UTC + 8] Гонконг, Иркутск, Пекин, Сингапур',
 		'8.75'	=> '[UTC + 8:45] Австралия',
-		'9'		=> '[UTC + 9] Иркутск, Сеул, Токио',
+		'9'		=> '[UTC + 9] Благовещенск, Сеул, Токио, Чита, Якутск',
 		'9.5'	=> '[UTC + 9:30] Аделаида, Дарвин',
-		'10'	=> '[UTC + 10] Благовещенск, Якутск',
+		'10'	=> '[UTC + 10] Владивосток, Магадан, Сахалин, Хабаровск',
 		'10.5'	=> '[UTC + 10:30] Лорд-Хау',
-		'11'	=> '[UTC + 11] Владивосток, Чита, Сахалин, Хабаровск',
+		'11'	=> '[UTC + 11] Среднеколымск, Чокурдах',
 		'11.5'	=> '[UTC + 11:30] о. Норфолк',
-		'12'	=> '[UTC + 12] Магадан, Камчатка, Фиджи',
+		'12'	=> '[UTC + 12] Анадырь, Петропавловск-Камчатский, Фиджи',
 		'12.75'	=> '[UTC + 12:45] о. Чатем',
 		'13'	=> '[UTC + 13] Нукуалофа',
 		'14'	=> '[UTC + 14] о. Лайн',
@@ -896,11 +901,11 @@ $lang = array_merge($lang, array(
 	'dateformats'	=> array(
 		'd M Y, H:i'			=> '10 янв 2005, 17:57',
 		'd M Y H:i'				=> '10 янв 2005 17:57',
-		'M jS, \'y, H:i'		=> 'Янв 1, \'07, 13:37',
+		'M j, \'y, H:i'			=> 'Янв 1, \'07, 13:37',
 		'D M d, Y g:i a'		=> 'Пн янв 10, 2005 5:57 pm',
-		'F jS, Y, g:i a'		=> 'Январь 1, 2007, 1:37 pm',
+		'F j, Y, g:i a'			=> 'Январь 1, 2007, 1:37 pm',
 		'|d M Y|, H:i'			=> 'Сегодня, 13:37 / 01 Янв 2007, 13:37',
-		'|F jS, Y|, g:i a'		=> 'Сегодня, 1:37 pm / Январь 1, 2007, 1:37 pm'
+		'|F j, Y|, g:i a'		=> 'Сегодня, 1:37 pm / Январь 1, 2007, 1:37 pm'
 	),
 
 	// The default dateformat which will be used on new installs in this language
@@ -909,4 +914,4 @@ $lang = array_merge($lang, array(
 
 ));
 
-?>
\ No newline at end of file
+?>
