@@ -178,6 +178,7 @@ $lang = array_merge($lang, array(
 
 	'QUOTE_DEPTH_EXCEEDED'		=> 'Максимально допустимое количество вложенных друг в друга цитат в сообщении: %1$d.',
 
+	'REMOTE_UPLOAD_TIMEOUT'		=> 'Файл не может быть загружен из-за превышения времени ожидания ответа сервера на запрос.',
 	'SAVE'						=> 'Сохранить',
 	'SAVE_DATE'					=> 'Последнее изменение',
 	'SAVE_DRAFT'				=> 'Сохранить черновик',
@@ -193,7 +194,7 @@ $lang = array_merge($lang, array(
 	'TOO_FEW_CHARS'				=> 'Ваше сообщение слишком короткое.',
 	'TOO_FEW_CHARS_LIMIT'		=> 'Ваше сообщение содержит %1$d символов. Минимальное количество символов, необходимое для публикации сообщения — %2$d.',
 	'TOO_FEW_POLL_OPTIONS'		=> 'Необходимо ввести по крайней мере два варианта ответа в опросе.',
-	'TOO_MANY_ATTACHMENTS'		=> 'Вложение невозможно, так как в сообщении достигнуто их максимальное количество: <b>%d</b>.',
+	'TOO_MANY_ATTACHMENTS'		=> 'Вложение невозможно, так как в сообщении достигнуто их максимальное количество: %d.',
 	'TOO_MANY_CHARS'			=> 'Ваше сообщение слишком длинное.',
 	'TOO_MANY_CHARS_POST'		=> 'Ваше сообщение содержит слишком много знаков: %1$d. Максимальное разрешённое количество: %2$d.',
 	'TOO_MANY_CHARS_SIG'		=> 'Ваша подпись содержит слишком много знаков: %1$d. Максимальное разрешённое количество: %2$d.',
@@ -219,8 +220,8 @@ $lang = array_merge($lang, array(
 	'VIEW_MESSAGE'				=> '%sПросмотреть ваше сообщение%s',
 	'VIEW_PRIVATE_MESSAGE'		=> '%sПросмотреть отправленные вами личные сообщения%s',
 
-	'WRONG_FILESIZE'			=> 'Слишком большой размер вложения. <br />Максимальный разрешённый размер: %1d %2s.',
+	'WRONG_FILESIZE'			=> 'Слишком большой размер вложения. <br />Максимальный разрешённый размер: %1$d %2$s.',
 	'WRONG_SIZE'				=> 'Размеры изображения должны быть не менее %1$d×%2$d и не более %3$d×%4$d. Размер отправленного изображения — %5$d×%6$d. Все размеры указаны в пикселах.',
 ));
 
-?>
\ No newline at end of file
+?>
